@@ -156,8 +156,7 @@ input_dir = function() {
 is_lyx = function() {
   args = commandArgs(TRUE)
   if (length(args) < 4) return(FALSE)
-  grepl('[.]Rnw$', args[1]) &&
-    !is.na(Sys.getenv('LyXDir', NA))
+  grepl('[.]Rnw$', args[1]) && !is.na(Sys.getenv('LyXDir', NA))
 }
 
 # scientific notation in TeX, HTML and reST
@@ -249,6 +248,8 @@ fix_options = function(options) {
       warning('You must not set both chunk options out.width and fig.retina')
     }
     options$dpi = options$dpi * r
+  } else {
+    options$fig.retina = 1
   }
 
   # deal with aliases: a1 is real option; a0 is alias
